@@ -1,20 +1,18 @@
 package Moose::Meta::Method::Accessor::Native::Code::execute;
+our $VERSION = '2.2206';
 
 use strict;
 use warnings;
 
-our $VERSION = '1.25';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _return_value {
-    my ( $self, $slot_access ) = @_;
+    my $self = shift;
+    my ($slot_access) = @_;
 
-    return "${slot_access}->(\@_)";
+    return $slot_access . '->(@_)';
 }
 
 no Moose::Role;
